Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(87)

Unified Diff: content/browser/child_process_launcher.h

Issue 1893313003: [mojo] Use a pipe path to initialise Mojo in elevated utility processes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/child_process_launcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/child_process_launcher.h
diff --git a/content/browser/child_process_launcher.h b/content/browser/child_process_launcher.h
index d5efc1e4dd6e7415568541f5bbe091671ac101c6..7d34ba925367105afb791b93d10bb863282386fe 100644
--- a/content/browser/child_process_launcher.h
+++ b/content/browser/child_process_launcher.h
@@ -16,7 +16,7 @@
#include "content/common/content_export.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/common/sandboxed_process_launcher_delegate.h"
-#include "mojo/edk/embedder/platform_channel_pair.h"
+#include "mojo/edk/embedder/scoped_platform_handle.h"
#if defined(OS_WIN)
#include "sandbox/win/src/sandbox_types.h"
@@ -155,8 +155,8 @@ class CONTENT_EXPORT ChildProcessLauncher : public base::NonThreadSafe {
// shutdown. Default behavior is to terminate the child.
const bool terminate_child_on_shutdown_;
- // Platform channel used to establish Mojo IPC.
- mojo::edk::PlatformChannelPair mojo_platform_channel_;
+ // Host side platform handle to establish Mojo IPC.
+ mojo::edk::ScopedPlatformHandle mojo_host_platform_handle_;
base::WeakPtrFactory<ChildProcessLauncher> weak_factory_;
« no previous file with comments | « no previous file | content/browser/child_process_launcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698